src.simple_sign.version API documentation
Description: Simple sign version.

# Module `src.simple_sign.version`

Simple sign version.

Expand source code

    """Simple sign version."""

    from importlib.metadata import PackageNotFoundError, version

    def get_version():
        """Return information about the version of this application."""
        __version__ = "0.0.0-dev"
        try:
            __version__ = version("simple-sign")
        except PackageNotFoundError:
            # package is not installed
            pass
        return __version__

## Functions

`def get_version()`

  Return information about the version of this application.

  Expand source code

      def get_version():
          """Return information about the version of this application."""
          __version__ = "0.0.0-dev"
          try:
              __version__ = version("simple-sign")
          except PackageNotFoundError:
              # package is not installed
              pass
          return __version__